LinchPin Hooks API
=========================================

The linchpin.hooks module manages the :doc:`hooks` functionality within
LinchPin.

.. automodule:: linchpin.hooks
    :members:
    :undoc-members:

.. automodule:: linchpin.hooks.action_managers
    :members:
    :undoc-members:
